==> haskell-configurator-pg-0.1.0.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-configurator-pg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator-pg
version: 0.1.0.3
id: configurator-pg-0.1.0.3-EkM7TuDEg6W91LJ26qD8qm
key: configurator-pg-0.1.0.3-EkM7TuDEg6W91LJ26qD8qm
license: BSD-3-Clause
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
           Copyright 2015-2016 Leon P Smith
           Copyright 2019 Robert Vollmert
maintainer: rob@vllmrt.net
author: Robert Vollmert
homepage: https://github.com/robx/configurator-pg
synopsis: Reduced parser for configurator-ng config files
description:
    This module provides a simplified and updated interface to the
    configuration file format of
    <https://hackage.haskell.org/package/configurator configurator> and
    <https://hackage.haskell.org/package/configurator-ng configurator-ng>.
    Its aim is primarily to allow updating programs that depend on
    configurator-ng to new versions of GHC without changing the
    configuration file format.
category: Configuration, Data
abi: ccd83052cb5133edf4e8f1741fe71834
exposed: True
exposed-modules:
    Data.Configurator
hidden-modules: Data.Configurator.Load Data.Configurator.Parser
                Data.Configurator.Syntax Data.Configurator.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/configurator-pg-0.1.0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/configurator-pg-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/configurator-pg-0.1.0.3
hs-libraries: HSconfigurator-pg-0.1.0.3-EkM7TuDEg6W91LJ26qD8qm
depends:
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t base-4.12.0.0
    containers-0.6.0.1 protolude-0.2.3-GImAE5SPJdhAOkFEJUpXPz
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-configurator-pg/html/configurator-pg.haddock
haddock-html: /usr/share/doc/haskell-configurator-pg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configurator-pg-0.1.0.3-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-configurator-pg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator-pg
version: 0.1.0.3
id: configurator-pg-0.1.0.3-V2s5d8i7ACJVwT4g8Jz8L
key: configurator-pg-0.1.0.3-V2s5d8i7ACJVwT4g8Jz8L
license: BSD-3-Clause
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
           Copyright 2015-2016 Leon P Smith
           Copyright 2019 Robert Vollmert
maintainer: rob@vllmrt.net
author: Robert Vollmert
homepage: https://github.com/robx/configurator-pg
synopsis: Reduced parser for configurator-ng config files
description:
    This module provides a simplified and updated interface to the
    configuration file format of
    <https://hackage.haskell.org/package/configurator configurator> and
    <https://hackage.haskell.org/package/configurator-ng configurator-ng>.
    Its aim is primarily to allow updating programs that depend on
    configurator-ng to new versions of GHC without changing the
    configuration file format.
category: Configuration, Data
abi: 20b1014566eae250fb161efd82dae14a
exposed: True
exposed-modules:
    Data.Configurator
hidden-modules: Data.Configurator.Load Data.Configurator.Parser
                Data.Configurator.Syntax Data.Configurator.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/configurator-pg-0.1.0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/configurator-pg-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/configurator-pg-0.1.0.3
hs-libraries: HSconfigurator-pg-0.1.0.3-V2s5d8i7ACJVwT4g8Jz8L
depends:
    attoparsec-0.13.2.3-C8ToaI6DNPR6ujzYigEqDi base-4.12.0.0
    containers-0.6.0.1 protolude-0.2.3-GImAE5SPJdhAOkFEJUpXPz
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-configurator-pg/html/configurator-pg.haddock
haddock-html: /usr/share/doc/haskell-configurator-pg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
